==> tmux-mem-cpu-load-3.5.1.tar.gz: tmux-mem-cpu-load-3.5.1/common/luts.h <==
#ifndef _luts_h
#define _luts_h

static const char cpu_percentage_lut[][32] = {
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour202]",
"#[fg=brightwhite,bg=colour202]",
"#[fg=brightwhite,bg=colour202]",
"#[fg=brightwhite,bg=colour202]",
"#[fg=brightwhite,bg=colour202]",
"#[fg=brightwhite,bg=colour202]",
"#[fg=brightwhite,bg=colour202]",
"#[fg=brightwhite,bg=colour202]",
"#[fg=brightwhite,bg=colour208]",
"#[fg=black,bg=colour208]",
"#[fg=black,bg=colour208]",
"#[fg=black,bg=colour208]",
"#[fg=black,bg=colour208]",
"#[fg=black,bg=colour208]",
"#[fg=black,bg=colour208]",
"#[fg=black,bg=colour214]",
"#[fg=black,bg=colour214]",
"#[fg=black,bg=colour214]",
"#[fg=black,bg=colour214]",
"#[fg=black,bg=colour214]",
"#[fg=black,bg=colour214]",
"#[fg=black,bg=colour214]",
"#[fg=black,bg=colour214]",
"#[fg=black,bg=colour220]",
"#[fg=black,bg=colour220]",
"#[fg=black,bg=colour220]",
"#[fg=black,bg=colour220]",
"#[fg=black,bg=colour220]",
"#[fg=black,bg=colour220]",
"#[fg=black,bg=colour220]",
"#[fg=black,bg=colour226]",
"#[fg=black,bg=colour226]",
"#[fg=black,bg=colour226]",
"#[fg=black,bg=colour226]",
"#[fg=black,bg=colour226]",
"#[fg=black,bg=colour226]",
"#[fg=black,bg=colour227]",
"#[fg=black,bg=colour227]",
"#[fg=black,bg=colour227]",
"#[fg=black,bg=colour227]",
"#[fg=black,bg=colour227]",
"#[fg=black,bg=colour227]",
"#[fg=black,bg=colour228]",
"#[fg=black,bg=colour228]",
"#[fg=black,bg=colour228]",
"#[fg=black,bg=colour228]",
"#[fg=black,bg=colour228]",
"#[fg=black,bg=colour229]",
"#[fg=black,bg=colour229]",
"#[fg=black,bg=colour229]",
"#[fg=black,bg=colour229]",
"#[fg=black,bg=colour229]",
"#[fg=black,bg=colour230]",
"#[fg=black,bg=colour230]",
"#[fg=black,bg=colour230]",
"#[fg=black,bg=colour230]",
"#[fg=black,bg=colour230]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]"
}; // end cpu_percentage_lut

static const char mem_lut[][32] = {
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour71]",
"#[fg=brightwhite,bg=colour71]",
"#[fg=brightwhite,bg=colour71]",
"#[fg=brightwhite,bg=colour107]",
"#[fg=brightwhite,bg=colour107]",
"#[fg=black,bg=colour107]",
"#[fg=black,bg=colour107]",
"#[fg=black,bg=colour108]",
"#[fg=black,bg=colour108]",
"#[fg=black,bg=colour108]",
"#[fg=black,bg=colour108]",
"#[fg=black,bg=colour108]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour150]",
"#[fg=black,bg=colour150]",
"#[fg=black,bg=colour186]",
"#[fg=black,bg=colour186]",
"#[fg=black,bg=colour186]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour181]",
"#[fg=black,bg=colour181]",
"#[fg=black,bg=colour181]",
"#[fg=black,bg=colour181]",
"#[fg=black,bg=colour187]",
"#[fg=black,bg=colour187]",
"#[fg=black,bg=colour187]",
"#[fg=black,bg=colour187]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour224]",
"#[fg=black,bg=colour224]",
"#[fg=black,bg=colour224]",
"#[fg=black,bg=colour224]",
"#[fg=black,bg=colour224]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]"
}; // end mem_lut

static const char load_lut[][32] = {
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=black,bg=colour103]",
"#[fg=black,bg=colour103]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour146]",
"#[fg=black,bg=colour146]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour195]",
"#[fg=black,bg=colour195]",
"#[fg=black,bg=colour195]",
"#[fg=black,bg=colour195]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]"
}; // end load_lut

#endif

==> tmux-mem-cpu-load-3.7.0.tar.gz: tmux-mem-cpu-load-3.7.0/common/luts.h <==
#ifndef _luts_h
#define _luts_h

static const char cpu_percentage_lut[][32] = {
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour19]",
"#[fg=brightwhite,bg=colour19]",
"#[fg=brightwhite,bg=colour19]",
"#[fg=brightwhite,bg=colour19]",
"#[fg=brightwhite,bg=colour19]",
"#[fg=brightwhite,bg=colour19]",
"#[fg=brightwhite,bg=colour20]",
"#[fg=brightwhite,bg=colour20]",
"#[fg=brightwhite,bg=colour20]",
"#[fg=brightwhite,bg=colour20]",
"#[fg=brightwhite,bg=colour20]",
"#[fg=brightwhite,bg=colour20]",
"#[fg=brightwhite,bg=colour20]",
"#[fg=brightwhite,bg=colour21]",
"#[fg=brightwhite,bg=colour21]",
"#[fg=brightwhite,bg=colour21]",
"#[fg=brightwhite,bg=colour21]",
"#[fg=brightwhite,bg=colour21]",
"#[fg=brightwhite,bg=colour21]",
"#[fg=brightwhite,bg=colour57]",
"#[fg=brightwhite,bg=colour57]",
"#[fg=brightwhite,bg=colour57]",
"#[fg=brightwhite,bg=colour57]",
"#[fg=brightwhite,bg=colour57]",
"#[fg=brightwhite,bg=colour57]",
"#[fg=brightwhite,bg=colour56]",
"#[fg=brightwhite,bg=colour56]",
"#[fg=brightwhite,bg=colour56]",
"#[fg=brightwhite,bg=colour56]",
"#[fg=brightwhite,bg=colour56]",
"#[fg=brightwhite,bg=colour56]",
"#[fg=brightwhite,bg=colour55]",
"#[fg=brightwhite,bg=colour55]",
"#[fg=brightwhite,bg=colour55]",
"#[fg=brightwhite,bg=colour55]",
"#[fg=brightwhite,bg=colour55]",
"#[fg=brightwhite,bg=colour55]",
"#[fg=brightwhite,bg=colour54]",
"#[fg=brightwhite,bg=colour54]",
"#[fg=brightwhite,bg=colour54]",
"#[fg=brightwhite,bg=colour54]",
"#[fg=brightwhite,bg=colour54]",
"#[fg=brightwhite,bg=colour54]",
"#[fg=brightwhite,bg=colour53]",
"#[fg=brightwhite,bg=colour53]",
"#[fg=brightwhite,bg=colour53]",
"#[fg=brightwhite,bg=colour53]",
"#[fg=brightwhite,bg=colour53]",
"#[fg=brightwhite,bg=colour53]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour52]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour88]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour124]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour160]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]",
"#[fg=brightwhite,bg=colour196]"
}; // end cpu_percentage_lut

static const char mem_lut[][32] = {
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour18]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour24]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour66]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour72]",
"#[fg=brightwhite,bg=colour71]",
"#[fg=brightwhite,bg=colour71]",
"#[fg=brightwhite,bg=colour71]",
"#[fg=brightwhite,bg=colour107]",
"#[fg=brightwhite,bg=colour107]",
"#[fg=black,bg=colour107]",
"#[fg=black,bg=colour107]",
"#[fg=black,bg=colour108]",
"#[fg=black,bg=colour108]",
"#[fg=black,bg=colour108]",
"#[fg=black,bg=colour108]",
"#[fg=black,bg=colour108]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour144]",
"#[fg=black,bg=colour150]",
"#[fg=black,bg=colour150]",
"#[fg=black,bg=colour186]",
"#[fg=black,bg=colour186]",
"#[fg=black,bg=colour186]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour180]",
"#[fg=black,bg=colour181]",
"#[fg=black,bg=colour181]",
"#[fg=black,bg=colour181]",
"#[fg=black,bg=colour181]",
"#[fg=black,bg=colour187]",
"#[fg=black,bg=colour187]",
"#[fg=black,bg=colour187]",
"#[fg=black,bg=colour187]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour224]",
"#[fg=black,bg=colour224]",
"#[fg=black,bg=colour224]",
"#[fg=black,bg=colour224]",
"#[fg=black,bg=colour224]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]"
}; // end mem_lut

static const char load_lut[][32] = {
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour16]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour17]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour59]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour60]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour102]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=brightwhite,bg=colour103]",
"#[fg=black,bg=colour103]",
"#[fg=black,bg=colour103]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour109]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour145]",
"#[fg=black,bg=colour146]",
"#[fg=black,bg=colour146]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour152]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour188]",
"#[fg=black,bg=colour195]",
"#[fg=black,bg=colour195]",
"#[fg=black,bg=colour195]",
"#[fg=black,bg=colour195]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]",
"#[fg=black,bg=colour231]"
}; // end load_lut

#endif
